# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""TBX11k simplified dataset for TB detection (cross validation fold 1)

* Split reference: first 62.6% of CXR for "train", 16% for "validation",
* 21.4% for "test"
* This split consists of non-TB and active TB samples
* "healthy", "latent TB", and "sick & non-TB" samples are all merged under the label "non-TB"
* This configuration resolution: 512 x 512 (default)
* See :py:mod:`ptbench.data.tbx11k_simplified_v2` for dataset details
"""

from clapper.logging import setup

from .. import return_subsets
from ..base_datamodule import BaseDataModule
from . import _maker

logger = setup(__name__.split(".")[0], format="%(levelname)s: %(message)s")


class Fold0Module(BaseDataModule):
    def __init__(
        self,
        train_batch_size=1,
        predict_batch_size=1,
        drop_incomplete_batch=False,
        multiproc_kwargs=None,
    ):
        super().__init__(
            train_batch_size=train_batch_size,
            predict_batch_size=predict_batch_size,
            drop_incomplete_batch=drop_incomplete_batch,
            multiproc_kwargs=multiproc_kwargs,
        )

    def setup(self, stage: str):
        self.dataset = _maker("fold_1")
        (
            self.train_dataset,
            self.validation_dataset,
            self.extra_validation_datasets,
            self.predict_dataset,
        ) = return_subsets(self.dataset)


datamodule = Fold0Module
