# Copyright © 2022 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later

import click

from clapper.click import AliasedGroup

from . import (
    aggregpred,
    compare,
    config,
    datamodule,
    evaluate,
    experiment,
    predict,
    predtojson,
    train,
    train_analysis,
)


@click.group(
    cls=AliasedGroup,
    context_settings=dict(help_option_names=["-?", "-h", "--help"]),
)
def cli():
    """Active Tuberculosis Detection On Chest X-Ray Images."""
    pass


cli.add_command(aggregpred.aggregpred)
cli.add_command(compare.compare)
cli.add_command(config.config)
cli.add_command(datamodule.datamodule)
cli.add_command(evaluate.evaluate)
cli.add_command(experiment.experiment)
cli.add_command(predict.predict)
cli.add_command(predtojson.predtojson)
cli.add_command(train.train)
cli.add_command(train_analysis.train_analysis)
